# call $ bin/frappy-server razorbillUC220T
# in frappy directory, with python with frappy libraries installed.

Node('UC220T.psi.ch',
     'A Razorbill UC220T controlled by a RP100 high voltage powersupply and a ACM1219 (AD7746) capacitance meter',
      interface='tcp://3000')

Mod('io1',
    'frappy_psi.RP100.RP100IO',
    'communication',
    uri='serial:///dev/ttyACM1?baudrate=9600+bytesize=8+parity=none+stopbits=1',
    visibility=2)
Mod('Tension',
    'frappy_psi.RP100.VoltageChannel',
    'Voltage Channel 1',
    temp='T',
    io='io1',
    target=Param(min=-200, max=200),
    max_target=120,
    min_target=-20,
    slew_rate=5,
    channel=1)
Mod('Compression',
    'frappy_psi.RP100.VoltageChannel',
    'Voltage Channel 2',
    temp='T',
    io='io1',
    target=Param(min=-200, max=200),
    max_target=120,
    min_target=-20,
    slew_rate=5,
    channel=2)

Mod('io2',
    'frappy_psi.ACM1219.ACM1219IO',
    'communication',
    uri='serial:///dev/ttyUSB1?baudrate=9600+bytesize=8+parity=none+stopbits=1',
    visibility=2)
Mod('C1',
    'frappy_psi.ACM1219.OneChannel',
    'channel 1',
    channel_enabled=True,
    channel=1,
    io='io2',
    group='cap')

Mod('io3',
    'frappy_psi.ACM1219.ACM1219IO',
    'communication',
    uri='serial:///dev/ttyUSB2?baudrate=9600+bytesize=8+parity=none+stopbits=1',
    visibility=2)
Mod('C2',
    'frappy_psi.ACM1219.OneChannel',
    'channel 1',
    channel_enabled=True,
    channel=1,
    io='io3',
    group='cap')

# Mod('C1',
#     'frappy_psi.ACM1219.Channel',
#     'channel 1',
#     group='cap')
# Mod('C2',
#     'frappy_psi.ACM1219.Channel',
#     'channel 2',
#     group='cap')
# Mod('C1C2',
#     'frappy_psi.ACM1219.BothChannels',
#     'Capacitance channels 1 and 2',
#     chan1='C1',
#     chan2='C2',
#     channels_enabled=True,
#     io='io2',
#     group='cap')
Mod('d',
    'frappy_psi.razorbill.Displacement',
    'razorbill displacement from capacitance',
    cap='C1',
    alpha290K=56.710,
    d0=95.443,
    Cp=0.01883,
    d0_curve={'a':4.21,'b':-0.00157,'c':-3.38e-5,'d':5.28e-8,'e':-6.93e-11},
    temp='T')
Mod('strain',
    'frappy_psi.razorbill.Strain',
    'Sample strain from force',
    displacement='d',
    L=3,
    )
Mod('F',
    'frappy_psi.razorbill.Force',
    'razorbill force from capacitance',
    cap='C2',
    alpha290K=374.23,
    f0=315.63,
    Cp=0.0755,
    f0_curve={'a':38.9,'b':-0.0147,'c':-0.000346,'d':8.96e-7,'e':-1.58e-9},
    temp='T')
Mod('stress',
    'frappy_psi.razorbill.Stress',
    'Sample stress from force',
    force='F',
    area=0.1,
    )
Mod('YM',
    'frappy_psi.razorbill.YoungsModulus',
    'Sample youngs modulus from stress and strain',
    stress='stress',
    strain='strain',
    )

Mod('T',
    'frappy_psi.razorbill.Temp',
    'dummy T written from client',
    target=Param(value=300, min=1, max=325),
    )


Mod('io4',
    'frappy_psi.ls372.StringIO',
    'the communication device',
    uri='tcp://192.168.3.3:7777',
    visibility=2
)
Mod('lsswitcher',
    'frappy_psi.ls372.Switcher',
    'Switcher control of Lsc controller',
    uri='tcp://192.168.3.3:7777',
    io='io4',
)
Mod('res',
    'frappy_psi.ls372.ResChannel',
    'resistivity',
    iexc='100uA',
    range='63.2mOhm',
    channel=1,
    switcher='lsswitcher',
)
